/*
 * Copyright (C) 2013-2018 MNEMOTIX <http://www.mnemotix.com/> and/or its affiliates
 * and other contributors as indicated by the @author tags.
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

/**
 * This file is part of the cortex package.
 *
 * Developped by Mnemotix <mathieu.rogelja@mnemotix.com>
 *
 * Date : 22/10/2018
 */

import React from 'react';
import {Mutation} from "react-apollo";
import PropTypes from 'prop-types';
import {Button} from 'semantic-ui-react';

import {cortexNotificationService, withContext} from '@mnemotix/cortex-core';
import {GraphQLMutations} from "@mnemotix/synaptix.js";

@withContext
export class RemoveObjectButton extends React.Component {
  static propTypes = {
    mutation: PropTypes.instanceOf(GraphQLMutations.RemoveObjectMutation).isRequired,
    objectRecord: PropTypes.object.isRequired,
    confirmMessage: PropTypes.string.isRequired,
    updateCounters: PropTypes.array,
    removeButtonLabel: PropTypes.string,
    onCompleted: PropTypes.func,
    onError: PropTypes.func,
    onAfter: PropTypes.func,
    buttonProps: PropTypes.object,
    successMessage: PropTypes.string,
    renderAs: PropTypes.func
  };

  state = {
    loading: false
  };

  constructor(props) {
    this.notificationService = props.notificationService || cortexNotificationService;
  }


  render() {
    const {t, removeLabel, buttonProps, mutation, renderAs} = this.props;

    return (
      <Mutation mutation={mutation.toGql()}>
        {(mutateFn, {data, loading, error}) => {
          let props = {
            loading,
            onClick: this._handleRemoveObject.bind(this, mutateFn)
          };

          return renderAs ? renderAs(props) : this.renderAsButton(props);
        }}
      </Mutation>
    )
  }

  renderAsButton(...props) {
    const {t, removeLabel, buttonProps} = this.props;

    return (
      <Button {...buttonProps} {...props}>
        {removeLabel || t("Remove")}
      </Button>
    )
  }

  _handleRemoveObject = (mutateFn, e) => {
    const {t, confirmMessage} = this.props;

    e.preventDefault();

    this.props.context.confirm({
      onConfirm: () => {
        this.removeObject(mutateFn);
      },
      content: confirmMessage
    })
  };

  async removeObject(mutateFn) {
    const {objectRecord, onCompleted, successMessage} = this.props;

    await this.props.mutation.apply({
      mutateFn,
      objectId: objectRecord.id
    });

    if (successMessage) {
      this.notificationService.alert(successMessage);
    }

    if (onCompleted) {
      onCompleted();
    }
  }
}
